ConnectUserPublicServiceBase class abstract

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteUser(ServiceCall call, PublicUserRequest request) → Future<PublicUserResponse>
deleteUser_Pre(ServiceCall call, Future<PublicUserRequest> request) → Future<PublicUserResponse>
getUserByToken(ServiceCall call, PublicUserRequest request) → Future<PublicUserResponse>
getUserByToken_Pre(ServiceCall call, Future<PublicUserRequest> request) → Future<PublicUserResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ping(ServiceCall call, Request request) → Future<Response>
ping_Pre(ServiceCall call, Future<Request> request) → Future<Response>
toString() → String
A string representation of this object.
inherited
updateUserEmail(ServiceCall call, PublicUserRequest request) → Future<PublicUserResponse>
updateUserEmail_Pre(ServiceCall call, Future<PublicUserRequest> request) → Future<PublicUserResponse>
updateUserGender(ServiceCall call, PublicUserRequest request) → Future<PublicUserResponse>
updateUserGender_Pre(ServiceCall call, Future<PublicUserRequest> request) → Future<PublicUserResponse>
updateUserPassword(ServiceCall call, PublicUserRequest request) → Future<PublicUserResponse>
updateUserPassword_Pre(ServiceCall call, Future<PublicUserRequest> request) → Future<PublicUserResponse>

Operators

operator ==(Object other) → bool
The equality operator.
inherited